/*********************************************************************************************************
*
*						prj bastao
*
**********************************************************************************************************
* Nome do Arquivo: Config_MPU6050.c
*
* Autor: Rodrigo Ramos 
*
* Depend?ncias:
*
* Microcontrolador: ATmega328p (M?dulo GY-521)
*
* Compilador: AVR(v5.4.0)
*
* Empresa: UFU 
*
* Informa??es: Biblioteca para defini??o da rotina de configura??o do 
*			   Motion Processing Units? MPU6050 - M?dulo GY-521(Hardware BASTAO Ver.001 2020 04)
*
*Vers?o: 000.1 Data:05/03/2020
*
*Modifica??es:
*			Data:05/03/2020 - vers?o 000.1
*                       
*                       
*                       
*********************************************************************************************************/
#include"Config_MPU6050.h"
// Initialize Class Variables //////////////////////////////////////////////////
uint8_t InertialSensor::uDevAddress = 0;
int16_t InertialSensor::AcX = 0;
int16_t InertialSensor::AcY = 0;
int16_t InertialSensor::AcZ = 0;
int16_t InertialSensor::Tmp = 0;
int16_t InertialSensor::GyX = 0;
int16_t InertialSensor::GyY = 0;
int16_t InertialSensor::GyZ = 0;
// Constructors ////////////////////////////////////////////////////////////////
InertialSensor::InertialSensor()
{
    
}
// Public Methods //////////////////////////////////////////////////////////////
void InertialSensor::initDevice(void)
{
    uDevAddress = 0x68;
    
    Wire.begin();
    Wire.beginTransmission(uDevAddress);
    
    /***********************************
     * Configura a escala (sensibilidade) do girosc?pio
     * registrador = 0x1B
     * Escala:
     *          0x00 = +/- 250  dps
     *          0x08 = +/- 500  dps
     *          0x10 = +/- 1000 dps
     *          0x18 = +/- 2000 dps
     **********************************/
    Wire.write(0x1B); 
    Wire.write(0x00);//Wire.write(0x18);//0x80 self-test GyX
    Wire.endTransmission(true);
    
     /***********************************
     * Configura a escala (sensibilidade) do acelerometro
     * registrador = 0x1C
     * Escala:
     *          0x00 = +/- 2 g
     *          0x08 = +/- 4 g
     *          0x10 = +/- 8 g
     *          0x18 = +/- 16 g
     **********************************/
    Wire.begin();
    Wire.beginTransmission(uDevAddress);
    Wire.write(0x1C); 
    Wire.write(0x00);//Wire.write(0x18);
    Wire.endTransmission(true);
    /*
      * Configura sinal de sincronismo externo (EXT_SYNC_SET)  e o filtro passa baixa digital (DLPF_CFG)
      * registrador = 0x1A
      */
      Wire.begin();
      Wire.beginTransmission(uDevAddress);
      Wire.write(0x1A); 
      Wire.write(0x01);//EXT_SYNC_SET -> desabilitado ; DLPF_CFG -> ver tabela no datasheet
      Wire.endTransmission(true);
    /*
     * Configura o SMPLRT_DIV
     * registrador = 0x19
     * lembrar que para o Girosc�pio:
     * Sample Rate = Gyroscope Output Rate / (1 + SMPLRT_DIV)
     * obs.: Gyroscope Output Rate ver registrador 0x26
     */
     Wire.begin();
     Wire.beginTransmission(uDevAddress);
     Wire.write(0x19); 
     Wire.write(0x00);//SMPLRT_DIV = 0
     Wire.endTransmission(true);
    /*
     * Configura srcClk entre outros...
     */
    //Inicializa o MPU-6050
    Wire.begin();
    Wire.beginTransmission(uDevAddress);
    Wire.write(0x6B); 
    Wire.write(0); 
    Wire.endTransmission(true);
}
void InertialSensor::initReadDevice(void)
{
    uDevAddress = 0x68;
    
    Wire.beginTransmission(uDevAddress);
    Wire.write(0x3B);  // starting with register 0x3B (ACCEL_XOUT_H)
    Wire.endTransmission(false);
    //Solicita os dados do sensor
    Wire.requestFrom(uDevAddress,14,true); 
}
void InertialSensor::read3Ac3Gy(void)
{
    AcX=Wire.read()<<8|Wire.read();  //0x3B (ACCEL_XOUT_H) & 0x3C (ACCEL_XOUT_L)     
    AcY=Wire.read()<<8|Wire.read();  //0x3D (ACCEL_YOUT_H) & 0x3E (ACCEL_YOUT_L)
    AcZ=Wire.read()<<8|Wire.read();  //0x3F (ACCEL_ZOUT_H) & 0x40 (ACCEL_ZOUT_L)
    Tmp=Wire.read()<<8|Wire.read();  //0x41 (TEMP_OUT_H) & 0x42 (TEMP_OUT_L)
    GyX=Wire.read()<<8|Wire.read();  //0x43 (GYRO_XOUT_H) & 0x44 (GYRO_XOUT_L)
    GyY=Wire.read()<<8|Wire.read();  //0x45 (GYRO_YOUT_H) & 0x46 (GYRO_YOUT_L)
    GyZ=Wire.read()<<8|Wire.read();  //0x47 (GYRO_ZOUT_H) & 0x48 (GYRO_ZOUT_L)
}
// Preinstantiate Objects //////////////////////////////////////////////////////
InertialSensor MPU6050 = InertialSensor();
